@@ -20,7 +20,6 @@
 */
 
 #include "proto/ficsprotocol.h"
-#include <gamemanager.h>
 #include "proto/ficsdialog.h"
 #include "proto/chatwidget.h"
 #include "settings.h"
@@ -204,7 +203,7 @@ void FicsProtocol::openGameDialog() {
 		return;
 	}
 	QDialog* dialog = new QDialog ( qApp->activeWindow() );
-	dialog->setWindowTitle(i18n("Chess server"));
+	dialog->setWindowTitle(i18nc("@title:window", "Chess server"));
 	auto mainLayout = new QVBoxLayout(dialog);
 	dialog->setLayout(mainLayout);
 	auto bBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel );
